@@ -288,13 +288,11 @@ function parseParameter(url, parameter) {
     return value;
 }
 
-function doSearch(search) {
+function doSearch(search, lat, lon) {
     waiting.state = "shown";
     var query = search;
     var url = SEARCH_URL + "?q=" + escape(query);
-    var lat = "";
-    var lon = "";
-    if(lat!=null && lat.length>0) {
+    if(lat!=null && lat.length>0 && lat!="NaN") {
         url += "&geocode=" + lat + "," + lon + ",20km";
     }
     autoRefreshURL = url;
